package nl.niels.lostadventure;

import org.newdawn.slick.Color;
import org.newdawn.slick.Graphics;
import org.newdawn.slick.TrueTypeFont;

public class Chat {
    private int maxrow;
    private int x;
    private int y;
    private TrueTypeFont font;
    private String[] lines;
    private Color[] colors;
    private Player inputplayer;

    public Chat(int maxrow, int x, int y, TrueTypeFont font, Player player) {
        this.inputplayer = player;
        this.font = font;
        this.maxrow = maxrow;
        this.lines = new String[maxrow];
        this.colors = new Color[maxrow];
        this.x = x;
        this.y = y;
        for(int i=0; i<maxrow; i++) {
            this.lines[i] = "";
            this.colors[i] = Color.white;
        }
    }

    public void addLine(String text, boolean showName, boolean local) {
        if(!isCommand(text)) {
            update();
            if(showName) {
                    lines[maxrow-1] = inputplayer.getName() + ": " + text;
            } else {
                    lines[maxrow-1] = text;
            }
            colors[maxrow-1] = Color.white;
        }
        if(!local) {
            //Send package
        }
    }

    public void addLine(String text, Color color, boolean showName, boolean local) {
        if(!isCommand(text)) {
            update();
            if(showName) {
                    lines[maxrow-1] = inputplayer.getName() + ": " + text;
            } else {
                    lines[maxrow-1] = text;
            }
            colors[maxrow-1] = color;
        }
        if(!local) {
            //Send package
        }
    }

    private void update() {
        for(int i=0; i<maxrow-1; i++) {
            lines[i] = lines[i+1];
            colors[i] = colors[i+1];
        }
    }

    public void draw(Graphics g) {
        for(int i=0; i<maxrow; i++) {
            g.setColor(colors[i]);
            g.setFont(font);
            g.drawString(lines[i], x, y+(i*16));
            g.setColor(Color.white);
        }
    }

    private boolean isCommand(String command) {
        String[] c = command.split(" ");
        String cmdname = c[0];
        if(cmdname.startsWith("/")) {
            if(cmdname.equals("/exit")) {
                System.exit(1);
            } else if(cmdname.equals("/setname")) {
                String oldname = inputplayer.getName();
                inputplayer.setName(c[1]);
                addLine(oldname + " set his name to " + c[1], Color.green, false, false);
            }else {
                addLine("Unknown command!", Color.red, false, true);
            }
            return true;
        }
        return false;
    }
}
