package nl.niels.lostadventure;

import java.util.Random;
import org.newdawn.slick.Color;
import org.newdawn.slick.GameContainer;
import org.newdawn.slick.Graphics;

public class World {
    private int worldnumber;
    private String worldgenerator;
    private WorldGenerator WorldGen;
    private int width;
    private int height;
    private Block[][] map;
    public float drawx = 0;
    public float drawy = 0;
    private Color sky;
    private int blocksize = 16;
    private int seed = 23121996;
    private Client client;

    public World(int i, String j, int k, int l, Client m) {
        client = m;
        worldnumber = i;
        worldgenerator = j;
        width = k;
        height = l;
        this.map = new Block[width][height];
        Random random = new Random();
        this.seed = random.nextInt(2147483647);
        int success;

        WorldGen = new WorldGenerator(worldgenerator, this, width, height);
        success = WorldGen.Generate();

        if(success == 0) {
            client.setErrorMsg("ERROR: World generator " + worldgenerator + " doesn't exist!");
            client.setError(true);
        } else if(success == 1) {
            System.out.println("World succesfull generated!");
        }
    }

    public void setBackground(Color color) {
        this.sky = color;
    }

    public void updateOnPlayer(Player player) {
        drawx = player.getX();
        drawy = player.getY();
    }

    public void draw(Graphics g, GameContainer gc) {
        gc.getGraphics().setBackground(sky); 
        int minx = (int) -Math.ceil(drawx/16);
        int maxx = (int) (Math.ceil(LostAdventure.screenwidth/16))+minx+2;
        int miny = (int) -Math.ceil(drawy/16);
        int maxy = (int) (Math.ceil(LostAdventure.screenheight/16))+miny+2;
        if(minx < 0) { minx = 0; }
        if(maxx > width) { maxx = width; }
        if(miny < 0) { miny = 0; }
        if(maxy > height) { maxy = height; }
        for(int x=minx; x<maxx; x++) {
            for(int y=miny; y<maxy; y++) {
                if(map[x][y].blockimage != null) {
                    map[x][y].blockimage.draw(drawx+x*blocksize, drawy+y*blocksize);
                }
                else if(map[x][y].blockcolor != null) {
                    g.setColor(map[x][y].blockcolor);
                    g.fillRect(drawx+x*blocksize, drawy+y*blocksize, blocksize, blocksize);
                }
            }
        }
    }

    public int getId() {
        return worldnumber;
    }

    public String getGeneratorName() {
        return worldgenerator;
    }

    public WorldGenerator getGenerator() {
        return WorldGen;
    }

    public int getBlocksize() {
        return blocksize;
    }

    public int getHeight() {
        return height;
    }

    public int getWidth() {
        return width;
    }

    public void setBlock(int x, int y, Block block) {
        map[x][y] = block;
    }
    
    public int getSeed() {
        return seed;
    }

    public void setBlock(Location location, Block block) {
        map[Math.round(location.getX())][Math.round(location.getY())] = block;
    }

    public Block checkPosition(int x, int y) {
        return map[x][y];
    }
}
